@@ -2,7 +2,7 @@
 #
 # This file is part of Config-Model-TkUI
 #
-# This software is Copyright (c) 2008-2018 by Dominique Dumont.
+# This software is Copyright (c) 2008-2018 by Dominique Dumont <ddumont@cpan.org>.
 #
 # This is free software, licensed under:
 #
@@ -15,6 +15,7 @@ use utf8;
 [
     [
         name    => 'SubSlave2',
+        gist => 'subslave2 with aa2:{aa2}',
         element => [
             [qw/aa2 ab2 ac2 ad2 Z/] => {
                 type       => 'leaf',
@@ -25,6 +26,7 @@ use utf8;
 
     [
         name    => 'SubSlave',
+        gist => 'subslave with aa:{aa}',
         element => [
             [qw/aa ab ac ad/] => {
                 type       => 'leaf',
@@ -39,6 +41,7 @@ use utf8;
 
     [
         name    => 'X_base_class2',
+        gist => 'x_base_class2 with X:{X}',
         element => [
             X => {
                 type       => 'leaf',
@@ -51,12 +54,13 @@ use utf8;
 
     [
         name    => 'X_base_class',
+        gist => 'x_base_class with X:{X}',
         include => 'X_base_class2',
     ],
 
     [
         name    => 'SlaveZ',
-        gist => 'Z:{Z} DX:{DX}',
+        gist => 'SlaveZ Z:{Z} DX:{DX}',
         element => [
             [qw/Z/] => {
                 type       => 'leaf',
@@ -76,6 +80,7 @@ use utf8;
 
     [
         name    => 'SlaveY',
+        gist => 'slaveY with Y:{Y}',
         element => [
             std_id => {
                 type       => 'hash',
@@ -146,6 +151,7 @@ things.
             file        => 'a_test.cds',
             auto_create => 1
         },
+        gist => 'M tree_macro:{tree_macro}',
         accept => [
             'foo.*' => { type => 'leaf', value_type => 'uniline'}
         ],
